from setuptools import setup

setup(name='xkcd_probability',
      version='0.5',
      description='Gaussian & Binomial distributions',
      packages=['xkcd_probability'],
      author="T.I. Szatmari",
      author_email="test-email@gmail.com",
      zip_safe=False)
